@@ -1,5 +1,9 @@
 package TestML::Library::Debug;
-use TestML();
+$TestML::Library::Debug::VERSION = '0.32';
+use TestML::Base;
+extends 'TestML::Library';
+
+no warnings 'redefine';
 
 sub WWW {
     require XXX;
